import os
import site
import importlib.util


def load_pytest_ini_from_site_packages(config):
    site_packages = site.getsitepackages()

    # Attempt to find the correct site-packages directory
    for site_package in site_packages:
        pytest_ini_path = os.path.join(site_package, 'src', 'pytest.ini')
        if os.path.exists(pytest_ini_path):
            print(f"Found pytest.ini at {pytest_ini_path}")
            # You can apply pytest settings here if necessary
            break
    else:
        print(f"Warning: pytest.ini not found in site-packages")


def pytest_configure(config):
    load_pytest_ini_from_site_packages(config)

    site_packages = site.getsitepackages()

    for site_package in site_packages:
        conftest_path = os.path.join(site_package, 'src', 'conftest.py')
        if os.path.exists(conftest_path):
            spec = importlib.util.spec_from_file_location("conftest", conftest_path)
            module = importlib.util.module_from_spec(spec)
            spec.loader.exec_module(module)
            print(f"Loaded conftest.py from {conftest_path}")
            break
    else:
        print(f"Warning: conftest.py not found in site-packages")
